summaryrefslogtreecommitdiff
path: root/sw/source/core/access/accpara.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sw/source/core/access/accpara.hxx')
-rw-r--r--sw/source/core/access/accpara.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/source/core/access/accpara.hxx b/sw/source/core/access/accpara.hxx
index d0e53dccda8f..bc604fbb5a65 100644
--- a/sw/source/core/access/accpara.hxx
+++ b/sw/source/core/access/accpara.hxx
@@ -34,8 +34,8 @@
#include <unordered_map>
class SwField;
-class SwTxtFrm;
-class SwTxtNode;
+class SwTextFrm;
+class SwTextNode;
class SwPaM;
class SwAccessiblePortionData;
class SwAccessibleHyperTextData;
@@ -90,8 +90,8 @@ class SwAccessibleParagraph :
SwParaChangeTrackingInfo* mpParaChangeTrackInfo; // #i108125#
- /// get the SwTxtNode (requires frame; check before)
- const SwTxtNode* GetTxtNode() const;
+ /// get the SwTextNode (requires frame; check before)
+ const SwTextNode* GetTextNode() const;
/// get the (accessible) text string (requires frame; check before)
OUString GetString();
@@ -240,7 +240,7 @@ protected:
public:
SwAccessibleParagraph( SwAccessibleMap& rInitMap,
- const SwTxtFrm& rTxtFrm );
+ const SwTextFrm& rTextFrm );
inline operator ::com::sun::star::accessibility::XAccessibleText *();